/*
* Many thanks to Ceptimus for the assistance with the code*******************************************



 * Tiny4kOLED - Drivers for SSD1306 controlled dot matrix OLED/PLED 128x32 displays
 *
 * Based on ssd1306xled, re-written and extended by Stephen Denne
 * from 2017-04-25 at https://github.com/datacute/Tiny4kOLED
 *
 */

// Choose your I2C implementation before including Tiny4kOLED.h
// The default is selected is Wire.h

// To use the Wire library:
//#include <Wire.h>

// To use the Adafruit's TinyWireM library:
#include <TinyWireM.h>

// To use the TinyI2C library from https://github.com/technoblogy/tiny-i2c
//#include <TinyI2CMaster.h>

// The blue OLED screen requires a long initialization on power on.
// The code to wait for it to be ready uses 20 bytes of program storage space
// If you are using a white OLED, this can be reclaimed by uncommenting
// the following line (before including Tiny4kOLED.h):
#define TINY4KOLED_QUICK_BEGIN

#include <Tiny4kOLED.h>
int buzzer = 4;
int sensorPin = 3;       //voltage divider to keep input below 5v on this sensor pin
static float low = 6.5;   //****************************************************************************************//set the low volts level here********************************************************************
float sensorValue = 0;   // variable to store the value coming from the sensor
char buffer[10];         // text string to print
float vin = 0;           //0 to 10V voltage of the battery
// ============================================================================

void setup() {


  pinMode(buzzer, OUTPUT);
  pinMode(5, OUTPUT);
  pinMode(2, OUTPUT);
  pinMode(1, OUTPUT);  //set the unused pins to digital outputs
  pinMode(6, OUTPUT);  //set the unused pins to digital outputs

  // This example is for a 128x64 screen
  oled.begin(128, 64, sizeof(tiny4koled_init_128x64br), tiny4koled_init_128x64br);
  oled.clear();
  oled.on();

  oled.setFontX2(FONT6X8P);
  oled.setCursor(20, 1);
  oled.print("Owned by");
  oled.setCursor(20, 4);
  oled.print("YourName");   //*******************************************************************************************************  //8 characters or modify the cursor position
  delay(4000);
  oled.clear();


  // Two rotations are supported,
  // The begin() method sets the rotation to 1.
  //oled.setRotation(0);

  // Some newer devices do not contain an external current reference.
  // Older devices may also support using the internal curret reference,
  // which provides more consistent brightness across devices.
  // The internal current reference can be configured as either low current, or high current.
  // Using true as the parameter value choses the high current internal current reference,
  // resulting in a brighter display, and a more effective contrast setting.
  oled.setInternalIref(true);
}




void loop() {

  getVolts();                                           // Thanks Ceptimus!

  int intVolts = (vin);                                 // seperate the integer
  int hundrethsVolts = (vin - intVolts) * 100.0 + 0.5;  // convert the floating number of volts into an interger of hundredths of volts
  sprintf(buffer, "%2d.", intVolts);                    // put the integer part and the decimal point in the buffer
  sprintf(buffer + 3, "%02d", hundrethsVolts);          // put the fractional part after the decimal point in buffer - note that %02d means that leading zeros are printed for values like .08 or .00

  if (vin > low) {


    oled.setFontX2(FONT6X8P);
    oled.setCursor(20, 1);
    oled.print("TX Batt");
    oled.setFontX2(FONT8X16P);
    oled.setCursor(7, 4);
    oled.print(buffer);  //print the voltage on the screen
    oled.print(" V");    //add a "V" to the end of the voltage display
    delay(5000);
    oled.setCursor(0, 4);
    oled.print("           ");
  }

  if (vin <= low) {

    oled.setCursor(2, 3);
    oled.setFontX2(FONT6X8P);
    oled.print("LOW VOLTS");     //print warning
    digitalWrite(buzzer, HIGH);  //sound the buzzer for a second
    delay(1000);
    digitalWrite(buzzer, LOW);
    oled.clear();
    oled.setCursor(10, 3);
    oled.setFontX2(FONT8X16P);
    oled.print(buffer);  //print the voltage on the screen
    oled.print(" V");    //add a "V" to the end of the voltage display
    delay(1000);
    oled.clear();
  }
}
void getVolts() {

  sensorValue = analogRead(sensorPin);   // read the value from the sensor:
  vin = sensorValue * (10.00 / 1024.0);  // Convert the analog reading (which goes from 0 - 1023) to a voltage (0 - 10V):
}
